import type { BeginUploadRequest } from "../models/BeginUploadRequest";
import type { BeginUploadResponse } from "../models/BeginUploadResponse";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { FileId } from "../models/FileId";
import type { UploadPart } from "../models/UploadPart";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
export declare class FilesService {
    /**
     * Begin a file upload.
     * @param requestBody File upload parameters.
     * @returns BeginUploadResponse Success.
     * @throws ApiError
     */
    static beginUpload(requestBody: BeginUploadRequest): Promise<BeginUploadResponse>;
    /**
     * Gets a remaining upload part for an in-progress upload.
     * @param fileId
     * @param uploadPartIndex
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static completeUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex, requestBody: CompleteUploadPartRequest): Promise<any>;
    /**
     * Gets a remaining upload part for an in-progress upload.
     * @param fileId
     * @param uploadPartIndex
     * @returns UploadPart Success.
     * @throws ApiError
     */
    static getUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex): Promise<UploadPart>;
    /**
     * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete.
     * @param fileId
     * @returns UploadPartList Success.
     * @throws ApiError
     */
    static getUploadParts(fileId: FileId): Promise<UploadPartList>;
}
